import { Construct } from '@aws-cdk/core';
/**
 * @stability stable
 */
export interface LinkedAccountConfig {
    /**
     * Account id which this metric comes from.
     *
     * @stability stable
     */
    readonly account: string;
    /**
     * Name of the alarm.
     *
     * If you don't specify a name, AWS CloudFormation generates a unique physical ID and uses that ID for the alarm name (recommended).
     *
     * @default Generated name
     * @stability stable
     */
    readonly alarmName?: string;
    /**
     * Description for the alarm.
     *
     * A developer-defined string that can be used to identify this alarm.
     *
     * @stability stable
     */
    readonly alarmDescription: string;
    /**
     * Enter the threshold amount in USD that must be exceeded to trigger the alarm e.g. (limit: 150).
     *
     * @stability stable
     */
    readonly thresholdAmount: number;
    /**
     * The email address that will be used to subcribe to the SNS topic for billing alert notifications e.g. ['hello@example.org'] or [''hello@example.org', 'admin@example.org'].
     *
     * @default - Not configured
     * @stability stable
     */
    readonly emailAddress?: string[];
    /**
     * The AWS Service to associate the alarm with e.g (AmazonDynamoDB).
     *
     * @default - Not configured.
     * @stability stable
     */
    readonly awsService?: string;
}
/**
 * @stability stable
 */
export interface LinkedAccountAlarmProps {
    /**
     * Imports a secret by secret name e.g 'prod/billing/topicArn'.
     *
     * A secret with this name must exist in the same account & region as the master/payer AWS account.
     *
     * @stability stable
     */
    readonly secretName: string;
    /**
     * Account configuration to configure linked account billing alarms with an exsiting SNS topic.
     *
     * @stability stable
     */
    readonly accountConfiguration: LinkedAccountConfig[];
}
/**
 * A construct to create a linked account billing alarm within a master/payer AWS account e.g (AWS Organization).
 *
 * @stability stable
 * @example
 *
 * .org'] },
 * { account: '123456789000', alarmDescription: 'Billing Alarm for AWS DynamoDB charge estimates only (Account: 123456789000)', thresholdAmount: 120, awsService: 'AmazonDynamoDB' },
 * ],
 */
export declare class LinkedAccountAlarm extends Construct {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, props: LinkedAccountAlarmProps);
    /**
     * Create billing alarm.
     *
     * @param topicArn string
     * @param query AlarmParams
     */
    private createBillingAlarm;
}
